@@ -19,23 +19,32 @@ Output = List[str]  # The different acceptable outputs of the NLP, string label
 Performance = float  # usually between zero & one (one is better)
 ModelEvaluator = Callable[[Input, Output], Performance]
 
-Category = str  # The different kinds of data produced by augmenters
+Category = str  # The different kinds of data produced by augmenters.
 
 
 class Augmenter(metaclass=abc.ABCMeta):
     @abc.abstractproperty
     def categories(self) -> Tuple[Category, ...]:
-        """Categories the augmenter can output"""
+        """Categories the augmenter can output.
+
+        Empty tuple if paraphrase."""
         ...
 
     @abc.abstractmethod
-    def convert_to(self, inp: Input, to: Category) -> Input:
+    def transform(self, inp: Input, to: Category = "") -> Input:
         """Transform the input to make it a member of the target category.
 
         Returns the input unchanged if the input is already a member of the target category or if
-        the transformation is not applicable."""
+        the transformation is not applicable.
+
+        The to argument doesn't need to be used for paraphrase."""
         ...
 
+    @property
+    def is_paraphrase(self) -> bool:
+        """Is this augmenter doing paraphrase."""
+        return len(self.categories) == 0
+
 
 class Variation(NamedTuple):
     text: Input
